@@ -132,12 +132,12 @@ static const FLOAT b97_params[][3][5] = {
     { 0.73604,  3.0270, -10.075,   20.611, -29.418}    /* Cab */
   }, {   /* N12  */
     { 0.0,          0.0,          0.0,          0.0,          0.0},          /* X   */
-    { 1.00000e+00,  3.24511e+00, -2.52893e+01,  1.44407e+01,  1.96870e+01},  /* Css */
-    { 1.00000e+00, -5.53170e+00,  3.07958e+01, -5.64196e+01,  3.21250e+01}   /* Cab */
+    { 1.00000e+00, -5.53170e+00,  3.07958e+01, -5.64196e+01,  3.21250e+01},  /* Css; coefficients flipped in original paper! */
+    { 1.00000e+00,  3.24511e+00, -2.52893e+01,  1.44407e+01,  1.96870e+01}   /* Cab; coefficients flipped in original paper! */
   }, {   /* N12-SX  */
-    { 0.0,          0.0,          0.0,          0.0,          0.0},          /* X   */
-    { 8.33615e-01,  3.24128e+00, -1.06407e+01, -1.60471e+01,  2.51047e+01},  /* Css */
-    { 2.63373e+00, -1.05450e+00, -7.29853e-01,  4.94024e+00, -7.31760e+00}   /* Cab */
+    { 0.0,          0.0,          0.0,          0.0,          0.0},          /* X   */ 
+    { 2.63373e+00, -1.05450e+00, -7.29853e-01,  4.94024e+00, -7.31760e+00},  /* Css; coefficients flipped in original paper! */
+    { 8.33615e-01,  3.24128e+00, -1.06407e+01, -1.60471e+01,  2.51047e+01}   /* Cab; coefficients flipped in original paper! */
   },
 };
 
